Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CLI ¶
type CLI struct {
Report Report `kong:"cmd,help='Analyze coverage file(s) and create a coverage report.'"`
Log struct {
Level slog.Level `enum:"DEBUG,INFO,WARN,ERROR" default:"INFO" help:"Set the app logging level."`
} `embed:"" prefix:"log-"`
Version kong.VersionFlag `kong:"help='Output fcov version and exit.'"`
// contains filtered or unexported fields
}
CLI is the command line interface of fcov.
type Output ¶
Output is a destination the report should be written to. If Filename is empty, the report will be written to stdout.
type OutputOption ¶
type OutputOption []Output
OutputOption is a custom type that parses the output option.
func (*OutputOption) UnmarshalText ¶
func (o *OutputOption) UnmarshalText(text []byte) error
UnmarshalText implements the encoding.TextUnmarshaler interface for OutputOption.
type Report ¶
type Report struct {
Files []string `arg:"" help:"One or more coverage files."` // not using 'existingfile' modifier since it makes it difficult to test with an in-memory FS
Filter []string `` /* 210-byte string literal not displayed */
FilterOutput []string `` /* 146-byte string literal not displayed */
FilterOutputFile string `` /* 157-byte string literal not displayed */
NestFiles bool `help:"Nest files under packages when rendering to text or Markdown. " default:"true" negatable:""`
Output OutputOption `` /* 357-byte string literal not displayed */
Thresholds ThresholdsOption `help:"Lower and upper threshold percentages for badge and health indicators. " default:"50,75"`
TrimPackagePrefix string `help:"Trim this prefix string from the package path in the output. "`
}
Report is the fcov report command.
type ThresholdsOption ¶
type ThresholdsOption struct {
Lower, Upper float64
}
ThresholdsOption is a custom type that parses the thresholds option.
func (*ThresholdsOption) UnmarshalText ¶
func (o *ThresholdsOption) UnmarshalText(text []byte) error
UnmarshalText implements the encoding.TextUnmarshaler interface for ThresholdsOption.
Click to show internal directories.
Click to hide internal directories.